@@ -9,8 +9,9 @@ from continuum.scenarios.rotations import Rotations
 from continuum.scenarios.permutations import Permutations
 from continuum.scenarios.segmentation import SegmentationClassIncremental
 from continuum.scenarios.hashed import HashedScenario
+from continuum.scenarios.online_fellowship import OnlineFellowship
 
-from continuum.scenarios.scenario_utils import create_subscenario
+from continuum.scenarios.scenario_utils import create_subscenario, encode_scenario
 
 __all__ = [
     "ContinualScenario",
@@ -20,5 +21,6 @@ __all__ = [
     "Permutations",
     "TransformationIncremental",
     "SegmentationClassIncremental",
-    "HashedScenario"
+    "HashedScenario",
+    "OnlineFellowship"
 ]
