@@ -7,7 +7,7 @@ from torch.utils.data import DataLoader
 import torchvision.transforms as trsf
 
 from continuum.tasks import TaskType
-from continuum.scenarios import ClassIncremental, InstanceIncremental, OnlineFellowship
+from continuum.scenarios import ClassIncremental, InstanceIncremental, OnlineFellowship, create_subscenario
 from continuum.datasets import (
     CIFAR10, CIFAR100, KMNIST, MNIST, CIFARFellowship, FashionMNIST, Fellowship, MNISTFellowship,
     InMemoryDataset, Fellowship, Core50
@@ -93,14 +93,37 @@ def test_Online_Fellowship(dataset7c, dataset10c, dataset20c):
     assert scenario[2].nb_classes == 20
 
 
+def test_Online_Fellowship_subscenarios(dataset7c, dataset10c, dataset20c):
+    scenario = OnlineFellowship([dataset7c, dataset10c, dataset20c])
+    sub_scenario = create_subscenario(scenario, np.arange(scenario.nb_tasks - 1))
+
+    for task_set in sub_scenario:
+        loader = DataLoader(task_set)
+        for _ in loader:
+            pass
+
+    assert sub_scenario.nb_tasks == scenario.nb_tasks - 1
+
+    task_order = np.arange(scenario.nb_tasks)
+    np.random.shuffle(task_order)
+    sub_scenario = create_subscenario(scenario, task_order)
+
+    for task_set in sub_scenario:
+        loader = DataLoader(task_set)
+        for _ in loader:
+            pass
+
+    assert sub_scenario.nb_tasks == scenario.nb_tasks
+
+
 @pytest.mark.parametrize("types,error", (
-    [[TaskType.IMAGE_PATH], False],
-    [[TaskType.H5, TaskType.IMAGE_PATH, TaskType.IMAGE_ARRAY, TaskType.TENSOR], False],
-    [[TaskType.H5, TaskType.IMAGE_PATH, TaskType.IMAGE_ARRAY, TaskType.TENSOR, TaskType.SEGMENTATION], True],
-    [[TaskType.H5, TaskType.IMAGE_PATH, TaskType.IMAGE_ARRAY, TaskType.TENSOR, TaskType.TEXT], True],
-    [[TaskType.H5, TaskType.IMAGE_PATH, TaskType.IMAGE_ARRAY, TaskType.TENSOR, TaskType.OBJ_DETECTION], True],
-    [[TaskType.SEGMENTATION, TaskType.OBJ_DETECTION], True],
-    [[TaskType.SEGMENTATION], False],
+        [[TaskType.IMAGE_PATH], False],
+        [[TaskType.H5, TaskType.IMAGE_PATH, TaskType.IMAGE_ARRAY, TaskType.TENSOR], False],
+        [[TaskType.H5, TaskType.IMAGE_PATH, TaskType.IMAGE_ARRAY, TaskType.TENSOR, TaskType.SEGMENTATION], True],
+        [[TaskType.H5, TaskType.IMAGE_PATH, TaskType.IMAGE_ARRAY, TaskType.TENSOR, TaskType.TEXT], True],
+        [[TaskType.H5, TaskType.IMAGE_PATH, TaskType.IMAGE_ARRAY, TaskType.TENSOR, TaskType.OBJ_DETECTION], True],
+        [[TaskType.SEGMENTATION, TaskType.OBJ_DETECTION], True],
+        [[TaskType.SEGMENTATION], False],
 ))
 def test_online_Fellowship_mixeddatatype(dataset10c, types, error):
     datasets = []
@@ -174,8 +197,8 @@ def test_online_Fellowship_mix_path_array(list_datasets):
 
 @pytest.mark.parametrize(
     "transformations", [
-        ([trsf.Resize(size=(16, 16)), trsf.ToTensor()]), #single for all
-        ([[trsf.ToTensor()], [trsf.ToTensor()], [trsf.ToTensor()]]) # one each
+        ([trsf.Resize(size=(16, 16)), trsf.ToTensor()]),  # single for all
+        ([[trsf.ToTensor()], [trsf.ToTensor()], [trsf.ToTensor()]])  # one each
     ]
 )
 def test_online_Fellowship_transformation(dataset7c, dataset10c, dataset20c, transformations):
@@ -193,7 +216,6 @@ def test_online_Fellowship_transformation(dataset7c, dataset10c, dataset20c, tra
 
 
 def test_online_Fellowship_transformation2(dataset7c, dataset10c, dataset20c):
-
     sizes = [16, 24, 40]
     transformations = [[trsf.Resize(size=(sizes[0], sizes[0])), trsf.ToTensor()],
                        [trsf.Resize(size=(sizes[1], sizes[1])), trsf.ToTensor()],
